@@ -7,7 +7,7 @@ from langchain_core.tools import BaseTool
 from langchain_core.tools.base import ToolException
 
 from codemie_tools.base.errors import TruncatedOutputError
-from codemie_tools.base.utils import get_encoding, sanitize_string
+from codemie_tools.base.utils import get_encoding, sanitize_string, humanize_error
 from codemie_tools.base.models import ToolOutputFormat
 
 logger = logging.getLogger(__name__)
@@ -42,7 +42,7 @@ class CodeMieTool(BaseTool):
             return super()._parse_input(tool_input, tool_call_id)
         except Exception as e:
             error_message = f"Error parsing tool input in {self.name}: {str(e)}"
-            logger.error(error_message)
+            logger.error(f"{error_message}.\nTool input: {tool_input}\nTool call id: {tool_call_id}")
             raise ToolException(error_message) from e
 
     def _run(self, *args, **kwargs):
@@ -62,6 +62,17 @@ class CodeMieTool(BaseTool):
     def execute(self, *args, **kwargs) -> Any:
         pass
 
+    def healthcheck(self):
+        try:
+            self._healthcheck()
+        except Exception as e:
+            return False, humanize_error(e)
+        return True, ""
+
+
+    def _healthcheck(self):
+        raise NotImplementedError(f"Healthcheck method is not implemented for {self.name}")
+
     def calculate_tokens_count(self, output: Any) -> int:
         encoding = get_encoding(self.base_llm_model_name)
 
