@@ -1,7 +1,7 @@
 from enum import Enum
 from typing import List, Optional
 
-from pydantic import BaseModel, model_validator
+from pydantic import BaseModel, model_validator, Field
 
 
 class ToolMetadata(BaseModel):
@@ -10,6 +10,14 @@ class ToolMetadata(BaseModel):
     label: Optional[str] = ''
     react_description: Optional[str] = ''
     user_description: Optional[str] = ''
+    settings_config: Optional[bool] = False
+    config_class: Optional[type] = Field(default=None, exclude=True)
+
+    @model_validator(mode='after')
+    def validate_settings_config(self) -> 'ToolMetadata':
+        if self.settings_config and self.config_class is None:
+            raise ValueError("config_class must be provided when settings_config is True")
+        return self
 
 
 class ToolSet(str, Enum):
@@ -48,8 +56,10 @@ class ToolSet(str, Enum):
 class Tool(BaseModel):
     name: str
     label: Optional[str] = None
-    settings_config: bool = False
+    settings_config: Optional[bool] = False
     user_description: Optional[str] = None
+    config_class: Optional[type] = Field(default=None, exclude=True)
+    tool_class: Optional[type] = Field(default=None, exclude=True)
 
     @model_validator(mode="before")
     def set_label(cls, values):
@@ -63,11 +73,17 @@ class Tool(BaseModel):
 
     @classmethod
     def from_metadata(cls, metadata: 'ToolMetadata', **kwargs):
+        config_class = _clazz if (_clazz := kwargs.get('config_class')) else metadata.config_class
+        settings_config = _settings_config if (
+            _settings_config := kwargs.get('settings_config')) else metadata.settings_config
+        tool_class = kwargs.get('tool_class')
         return cls(
             name=metadata.name,
             label=metadata.label or None,
             user_description=metadata.user_description or None,
-            **kwargs
+            config_class=config_class,
+            settings_config=settings_config,
+            tool_class=tool_class
         )
 
 
@@ -75,10 +91,16 @@ class ToolKit(BaseModel):
     toolkit: str
     tools: List[Tool]
     label: Optional[str] = ""
-    settings_config: bool = False
+    settings_config: Optional[bool] = False
     is_external: bool = False
+    config_class: Optional[type] = None
 
 
 class ToolOutputFormat(str, Enum):
     TEXT = "text"
     MARKDOWN = "markdown"
+
+
+class CodeMieToolConfig(BaseModel):
+    """Empty Pydantic class for CodeMie tool configuration."""
+    pass
