@@ -31,4 +31,5 @@ class SearchElasticIndexResults:
     @classmethod
     def search(cls, index: str, query: str, elastic_config: ElasticConfig):
         client = cls._get_client(elastic_config=elastic_config)
-        return client.search(index=index, body=query)
+        response = client.search(index=index, body=query)
+        return response.body
