@@ -31,11 +31,27 @@ TYPE_UNKNOWN: str = "unknown"
 
 
 class GitCredentials(BaseModel):
-    token: str
-    token_name: Optional[str] = None
-    repo_link: str
-    base_branch: str
-    repo_type: str = Field(default=TYPE_UNKNOWN)
+    token: str = Field(
+        description="Personal Access Token with appropriate permissions for repository access",
+        example="ghp_1a2b3c4d5e6f7g8h9i0j..."
+    )
+    token_name: Optional[str] = Field(
+        default=None,
+        description="Token name or identifier for reference",
+        example="my-project-token"
+    )
+    repo_link: str = Field(
+        description="URL to your Git server, e.g. https://gitlab.example.com or https://github.com",
+        example="https://gitlab.example.com/username/repository.git"
+    )
+    base_branch: str = Field(
+        description="Base branch to use, defaults to main/master",
+        example="main"
+    )
+    repo_type: str = Field(
+        default=TYPE_UNKNOWN,
+        description="Repository type: github, gitlab, bitbucket, or azure_devops"
+    )
 
 
 def init_gitlab_api_wrapper(
